Class: Aws::IoTDataPlane::Types::GetConnectionResponse

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-iotdataplane/types.rb

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#clean_sessionBoolean

Indicates whether the client is using a clean session. Returns ‘true` for clean sessions or `false` for persistent sessions.

Returns:

  • (Boolean)


225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
# File 'lib/aws-sdk-iotdataplane/types.rb', line 225

class GetConnectionResponse < Struct.new(
  :connected,
  :thing_name,
  :clean_session,
  :source_ip,
  :source_port,
  :target_ip,
  :target_port,
  :keep_alive_duration,
  :connected_since,
  :disconnected_since,
  :disconnect_reason,
  :session_expiry,
  :client_id,
  :vpc_endpoint_id)
  SENSITIVE = []
  include Aws::Structure
end

#client_idString

The unique identifier of the MQTT client. This is the same client ID that was used when the client established the connection.

Returns:

  • (String)


225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
# File 'lib/aws-sdk-iotdataplane/types.rb', line 225

class GetConnectionResponse < Struct.new(
  :connected,
  :thing_name,
  :clean_session,
  :source_ip,
  :source_port,
  :target_ip,
  :target_port,
  :keep_alive_duration,
  :connected_since,
  :disconnected_since,
  :disconnect_reason,
  :session_expiry,
  :client_id,
  :vpc_endpoint_id)
  SENSITIVE = []
  include Aws::Structure
end

#connectedBoolean

The connection state of the client. Returns ‘true` if the client is currently connected, or `false` if the client is not connected.

Returns:

  • (Boolean)


225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
# File 'lib/aws-sdk-iotdataplane/types.rb', line 225

class GetConnectionResponse < Struct.new(
  :connected,
  :thing_name,
  :clean_session,
  :source_ip,
  :source_port,
  :target_ip,
  :target_port,
  :keep_alive_duration,
  :connected_since,
  :disconnected_since,
  :disconnect_reason,
  :session_expiry,
  :client_id,
  :vpc_endpoint_id)
  SENSITIVE = []
  include Aws::Structure
end

#connected_sinceInteger

Unix timestamp (in milliseconds) indicating when the client connected. Present only when connected is true.

Returns:

  • (Integer)


225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
# File 'lib/aws-sdk-iotdataplane/types.rb', line 225

class GetConnectionResponse < Struct.new(
  :connected,
  :thing_name,
  :clean_session,
  :source_ip,
  :source_port,
  :target_ip,
  :target_port,
  :keep_alive_duration,
  :connected_since,
  :disconnected_since,
  :disconnect_reason,
  :session_expiry,
  :client_id,
  :vpc_endpoint_id)
  SENSITIVE = []
  include Aws::Structure
end

#disconnect_reasonString

The reason for the last disconnection, if the client is currently disconnected. See the [developer guide] for valid disconnect reasons.

[1]: docs.aws.amazon.com/iot/latest/developerguide/life-cycle-events.html#connect-disconnect

Returns:

  • (String)


225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
# File 'lib/aws-sdk-iotdataplane/types.rb', line 225

class GetConnectionResponse < Struct.new(
  :connected,
  :thing_name,
  :clean_session,
  :source_ip,
  :source_port,
  :target_ip,
  :target_port,
  :keep_alive_duration,
  :connected_since,
  :disconnected_since,
  :disconnect_reason,
  :session_expiry,
  :client_id,
  :vpc_endpoint_id)
  SENSITIVE = []
  include Aws::Structure
end

#disconnected_sinceInteger

Unix timestamp (in milliseconds) indicating when the client disconnected. Present only when connected is false. This information is available for 30 minutes after the client disconnects.

Returns:

  • (Integer)


225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
# File 'lib/aws-sdk-iotdataplane/types.rb', line 225

class GetConnectionResponse < Struct.new(
  :connected,
  :thing_name,
  :clean_session,
  :source_ip,
  :source_port,
  :target_ip,
  :target_port,
  :keep_alive_duration,
  :connected_since,
  :disconnected_since,
  :disconnect_reason,
  :session_expiry,
  :client_id,
  :vpc_endpoint_id)
  SENSITIVE = []
  include Aws::Structure
end

#keep_alive_durationInteger

The keep-alive interval in seconds that the client specified when establishing the connection.

Returns:

  • (Integer)


225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
# File 'lib/aws-sdk-iotdataplane/types.rb', line 225

class GetConnectionResponse < Struct.new(
  :connected,
  :thing_name,
  :clean_session,
  :source_ip,
  :source_port,
  :target_ip,
  :target_port,
  :keep_alive_duration,
  :connected_since,
  :disconnected_since,
  :disconnect_reason,
  :session_expiry,
  :client_id,
  :vpc_endpoint_id)
  SENSITIVE = []
  include Aws::Structure
end

#session_expiryInteger

The session expiry interval in seconds for the MQTT client connection. This is configured by the user. This value indicates how long the session will remain active after the client disconnects.

Returns:

  • (Integer)


225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
# File 'lib/aws-sdk-iotdataplane/types.rb', line 225

class GetConnectionResponse < Struct.new(
  :connected,
  :thing_name,
  :clean_session,
  :source_ip,
  :source_port,
  :target_ip,
  :target_port,
  :keep_alive_duration,
  :connected_since,
  :disconnected_since,
  :disconnect_reason,
  :session_expiry,
  :client_id,
  :vpc_endpoint_id)
  SENSITIVE = []
  include Aws::Structure
end

#source_ipString

The IP address of the client that initiated the connection.

Returns:

  • (String)


225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
# File 'lib/aws-sdk-iotdataplane/types.rb', line 225

class GetConnectionResponse < Struct.new(
  :connected,
  :thing_name,
  :clean_session,
  :source_ip,
  :source_port,
  :target_ip,
  :target_port,
  :keep_alive_duration,
  :connected_since,
  :disconnected_since,
  :disconnect_reason,
  :session_expiry,
  :client_id,
  :vpc_endpoint_id)
  SENSITIVE = []
  include Aws::Structure
end

#source_portInteger

The client’s source port.

Returns:

  • (Integer)


225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
# File 'lib/aws-sdk-iotdataplane/types.rb', line 225

class GetConnectionResponse < Struct.new(
  :connected,
  :thing_name,
  :clean_session,
  :source_ip,
  :source_port,
  :target_ip,
  :target_port,
  :keep_alive_duration,
  :connected_since,
  :disconnected_since,
  :disconnect_reason,
  :session_expiry,
  :client_id,
  :vpc_endpoint_id)
  SENSITIVE = []
  include Aws::Structure
end

#target_ipString

The IP address of the Amazon Web Services IoT Core endpoint that the client connected to. For clients connected to VPC endpoints, this is the private IP address of the network interface the client is connected to.

Returns:

  • (String)


225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
# File 'lib/aws-sdk-iotdataplane/types.rb', line 225

class GetConnectionResponse < Struct.new(
  :connected,
  :thing_name,
  :clean_session,
  :source_ip,
  :source_port,
  :target_ip,
  :target_port,
  :keep_alive_duration,
  :connected_since,
  :disconnected_since,
  :disconnect_reason,
  :session_expiry,
  :client_id,
  :vpc_endpoint_id)
  SENSITIVE = []
  include Aws::Structure
end

#target_portInteger

The port number of the Amazon Web Services IoT Core endpoint that the client connected to.

Returns:

  • (Integer)


225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
# File 'lib/aws-sdk-iotdataplane/types.rb', line 225

class GetConnectionResponse < Struct.new(
  :connected,
  :thing_name,
  :clean_session,
  :source_ip,
  :source_port,
  :target_ip,
  :target_port,
  :keep_alive_duration,
  :connected_since,
  :disconnected_since,
  :disconnect_reason,
  :session_expiry,
  :client_id,
  :vpc_endpoint_id)
  SENSITIVE = []
  include Aws::Structure
end

#thing_nameString

The name of the thing associated with the principal of the MQTT client, if applicable.

Returns:

  • (String)


225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
# File 'lib/aws-sdk-iotdataplane/types.rb', line 225

class GetConnectionResponse < Struct.new(
  :connected,
  :thing_name,
  :clean_session,
  :source_ip,
  :source_port,
  :target_ip,
  :target_port,
  :keep_alive_duration,
  :connected_since,
  :disconnected_since,
  :disconnect_reason,
  :session_expiry,
  :client_id,
  :vpc_endpoint_id)
  SENSITIVE = []
  include Aws::Structure
end

#vpc_endpoint_idString

The ID of the VPC endpoint. Present for clients connected to IoT Core via a [VPC endpoint].

[1]: docs.aws.amazon.com/iot/latest/developerguide/IoTCore-VPC.html

Returns:

  • (String)


225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
# File 'lib/aws-sdk-iotdataplane/types.rb', line 225

class GetConnectionResponse < Struct.new(
  :connected,
  :thing_name,
  :clean_session,
  :source_ip,
  :source_port,
  :target_ip,
  :target_port,
  :keep_alive_duration,
  :connected_since,
  :disconnected_since,
  :disconnect_reason,
  :session_expiry,
  :client_id,
  :vpc_endpoint_id)
  SENSITIVE = []
  include Aws::Structure
end