Class: Aws::IoTDataPlane::Types::GetRetainedMessageRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::IoTDataPlane::Types::GetRetainedMessageRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-iotdataplane/types.rb
Overview
The input for the GetRetainedMessage operation.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#topic ⇒ String
The topic name of the retained message to retrieve.
Instance Attribute Details
#topic ⇒ String
The topic name of the retained message to retrieve.
250 251 252 253 254 |
# File 'lib/aws-sdk-iotdataplane/types.rb', line 250 class GetRetainedMessageRequest < Struct.new( :topic) SENSITIVE = [] include Aws::Structure end |