Class: Aws::IoTDataPlane::Types::ListSubscriptionsResponse

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-iotdataplane/types.rb

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#next_tokenString

The token to use to get the next set of results, or null if there are no additional results.

Returns:



465
466
467
468
469
470
# File 'lib/aws-sdk-iotdataplane/types.rb', line 465

class ListSubscriptionsResponse < Struct.new(
  :subscriptions,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#subscriptionsArray<Types::SubscriptionSummary>

A list of topic filters and their associated Quality of Service (QoS) levels that the client is subscribed to.

Returns:



465
466
467
468
469
470
# File 'lib/aws-sdk-iotdataplane/types.rb', line 465

class ListSubscriptionsResponse < Struct.new(
  :subscriptions,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end