Class: Aws::IoTDataPlane::Types::PublishRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::IoTDataPlane::Types::PublishRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-iotdataplane/types.rb
Overview
The input for the Publish operation.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#content_type ⇒ String
A UTF-8 encoded string that describes the content of the publishing message.
-
#correlation_data ⇒ String
The base64-encoded binary data used by the sender of the request message to identify which request the response message is for when it’s received.
-
#message_expiry ⇒ Integer
A user-defined integer value that represents the message expiry interval in seconds.
-
#payload ⇒ String
The message body.
-
#payload_format_indicator ⇒ String
An ‘Enum` string value that indicates whether the payload is formatted as UTF-8.
-
#qos ⇒ Integer
The Quality of Service (QoS) level.
-
#response_topic ⇒ String
A UTF-8 encoded string that’s used as the topic name for a response message.
-
#retain ⇒ Boolean
A Boolean value that determines whether to set the RETAIN flag when the message is published.
-
#topic ⇒ String
The name of the MQTT topic.
-
#user_properties ⇒ String
A JSON string that contains an array of JSON objects.
Instance Attribute Details
#content_type ⇒ String
A UTF-8 encoded string that describes the content of the publishing message.
370 371 372 373 374 375 376 377 378 379 380 381 382 383 |
# File 'lib/aws-sdk-iotdataplane/types.rb', line 370 class PublishRequest < Struct.new( :topic, :qos, :retain, :payload, :user_properties, :payload_format_indicator, :content_type, :response_topic, :correlation_data, :message_expiry) SENSITIVE = [] include Aws::Structure end |
#correlation_data ⇒ String
The base64-encoded binary data used by the sender of the request message to identify which request the response message is for when it’s received. ‘correlationData` is an HTTP header value in the API.
370 371 372 373 374 375 376 377 378 379 380 381 382 383 |
# File 'lib/aws-sdk-iotdataplane/types.rb', line 370 class PublishRequest < Struct.new( :topic, :qos, :retain, :payload, :user_properties, :payload_format_indicator, :content_type, :response_topic, :correlation_data, :message_expiry) SENSITIVE = [] include Aws::Structure end |
#message_expiry ⇒ Integer
A user-defined integer value that represents the message expiry interval in seconds. If absent, the message doesn’t expire. For more information about the limits of ‘messageExpiry`, see [Amazon Web Services IoT Core message broker and protocol limits and quotas ][1] from the Amazon Web Services Reference Guide.
[1]: docs.aws.amazon.com/general/latest/gr/iot-core.html#message-broker-limits
370 371 372 373 374 375 376 377 378 379 380 381 382 383 |
# File 'lib/aws-sdk-iotdataplane/types.rb', line 370 class PublishRequest < Struct.new( :topic, :qos, :retain, :payload, :user_properties, :payload_format_indicator, :content_type, :response_topic, :correlation_data, :message_expiry) SENSITIVE = [] include Aws::Structure end |
#payload ⇒ String
The message body. MQTT accepts text, binary, and empty (null) message payloads.
Publishing an empty (null) payload with retain = ‘true` deletes the retained message identified by topic from Amazon Web Services IoT Core.
370 371 372 373 374 375 376 377 378 379 380 381 382 383 |
# File 'lib/aws-sdk-iotdataplane/types.rb', line 370 class PublishRequest < Struct.new( :topic, :qos, :retain, :payload, :user_properties, :payload_format_indicator, :content_type, :response_topic, :correlation_data, :message_expiry) SENSITIVE = [] include Aws::Structure end |
#payload_format_indicator ⇒ String
An ‘Enum` string value that indicates whether the payload is formatted as UTF-8. `payloadFormatIndicator` is an HTTP header value in the API.
370 371 372 373 374 375 376 377 378 379 380 381 382 383 |
# File 'lib/aws-sdk-iotdataplane/types.rb', line 370 class PublishRequest < Struct.new( :topic, :qos, :retain, :payload, :user_properties, :payload_format_indicator, :content_type, :response_topic, :correlation_data, :message_expiry) SENSITIVE = [] include Aws::Structure end |
#qos ⇒ Integer
The Quality of Service (QoS) level. The default QoS level is 0.
370 371 372 373 374 375 376 377 378 379 380 381 382 383 |
# File 'lib/aws-sdk-iotdataplane/types.rb', line 370 class PublishRequest < Struct.new( :topic, :qos, :retain, :payload, :user_properties, :payload_format_indicator, :content_type, :response_topic, :correlation_data, :message_expiry) SENSITIVE = [] include Aws::Structure end |
#response_topic ⇒ String
A UTF-8 encoded string that’s used as the topic name for a response message. The response topic is used to describe the topic which the receiver should publish to as part of the request-response flow. The topic must not contain wildcard characters.
370 371 372 373 374 375 376 377 378 379 380 381 382 383 |
# File 'lib/aws-sdk-iotdataplane/types.rb', line 370 class PublishRequest < Struct.new( :topic, :qos, :retain, :payload, :user_properties, :payload_format_indicator, :content_type, :response_topic, :correlation_data, :message_expiry) SENSITIVE = [] include Aws::Structure end |
#retain ⇒ Boolean
A Boolean value that determines whether to set the RETAIN flag when the message is published.
Setting the RETAIN flag causes the message to be retained and sent to new subscribers to the topic.
Valid values: ‘true` | `false`
Default value: ‘false`
370 371 372 373 374 375 376 377 378 379 380 381 382 383 |
# File 'lib/aws-sdk-iotdataplane/types.rb', line 370 class PublishRequest < Struct.new( :topic, :qos, :retain, :payload, :user_properties, :payload_format_indicator, :content_type, :response_topic, :correlation_data, :message_expiry) SENSITIVE = [] include Aws::Structure end |
#topic ⇒ String
The name of the MQTT topic.
370 371 372 373 374 375 376 377 378 379 380 381 382 383 |
# File 'lib/aws-sdk-iotdataplane/types.rb', line 370 class PublishRequest < Struct.new( :topic, :qos, :retain, :payload, :user_properties, :payload_format_indicator, :content_type, :response_topic, :correlation_data, :message_expiry) SENSITIVE = [] include Aws::Structure end |
#user_properties ⇒ String
A JSON string that contains an array of JSON objects. If you don’t use Amazon Web Services SDK or CLI, you must encode the JSON string to base64 format before adding it to the HTTP header. ‘userProperties` is an HTTP header value in the API.
The following example ‘userProperties` parameter is a JSON string which represents two User Properties. Note that it needs to be base64-encoded:
‘[“alpha”, “45”]`
370 371 372 373 374 375 376 377 378 379 380 381 382 383 |
# File 'lib/aws-sdk-iotdataplane/types.rb', line 370 class PublishRequest < Struct.new( :topic, :qos, :retain, :payload, :user_properties, :payload_format_indicator, :content_type, :response_topic, :correlation_data, :message_expiry) SENSITIVE = [] include Aws::Structure end |