Class: Aws::IoTDataPlane::Types::SendDirectMessageResponse

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-iotdataplane/types.rb

Overview

The output from the SendDirectMessage operation.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#messageString

The status message indicating the result of the operation.

Returns:

  • (String)


770
771
772
773
774
775
# File 'lib/aws-sdk-iotdataplane/types.rb', line 770

class SendDirectMessageResponse < Struct.new(
  :message,
  :trace_id)
  SENSITIVE = []
  include Aws::Structure
end

#trace_idString

A unique identifier for the request. Include this value when contacting Amazon Web Services Support for troubleshooting.

Returns:

  • (String)


770
771
772
773
774
775
# File 'lib/aws-sdk-iotdataplane/types.rb', line 770

class SendDirectMessageResponse < Struct.new(
  :message,
  :trace_id)
  SENSITIVE = []
  include Aws::Structure
end