Class: Aws::IoTDataPlane::Types::SubscriptionSummary

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-iotdataplane/types.rb

Overview

Contains information about a subscription for an MQTT client, including the topic filter and Quality of Service (QoS) level.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#qosInteger

The Quality of Service (QoS) level for the subscription. Valid values are 0 (at most once) and 1 (at least once).

Returns:

  • (Integer)


802
803
804
805
806
807
# File 'lib/aws-sdk-iotdataplane/types.rb', line 802

class SubscriptionSummary < Struct.new(
  :topic_filter,
  :qos)
  SENSITIVE = []
  include Aws::Structure
end

#topic_filterString

The topic filter pattern that the client is subscribed to. May include MQTT wildcards such as + (single-level) and # (multi-level).

Returns:

  • (String)


802
803
804
805
806
807
# File 'lib/aws-sdk-iotdataplane/types.rb', line 802

class SubscriptionSummary < Struct.new(
  :topic_filter,
  :qos)
  SENSITIVE = []
  include Aws::Structure
end