Class: Aws::IoTDataPlane::Client
- Inherits:
-
Seahorse::Client::Base
- Object
- Seahorse::Client::Base
- Aws::IoTDataPlane::Client
- Includes:
- ClientStubs
- Defined in:
- lib/aws-sdk-iotdataplane/client.rb
Overview
An API client for IoTDataPlane. To construct a client, you need to configure a ‘:region` and `:credentials`.
client = Aws::IoTDataPlane::Client.new(
region: region_name,
credentials: credentials,
# ...
)
For details on configuring region and credentials see the [developer guide](/sdk-for-ruby/v3/developer-guide/setup-config.html).
See #initialize for a full list of supported configuration options.
Class Attribute Summary collapse
- .identifier ⇒ Object readonly private
API Operations collapse
-
#delete_connection(params = {}) ⇒ Struct
Disconnects a connected MQTT client from Amazon Web Services IoT Core.
-
#delete_thing_shadow(params = {}) ⇒ Types::DeleteThingShadowResponse
Deletes the shadow for the specified thing.
-
#get_connection(params = {}) ⇒ Types::GetConnectionResponse
Retrieves connection information for the specified MQTT client.
-
#get_retained_message(params = {}) ⇒ Types::GetRetainedMessageResponse
Gets the details of a single retained message for the specified topic.
-
#get_thing_shadow(params = {}) ⇒ Types::GetThingShadowResponse
Gets the shadow for the specified thing.
-
#list_named_shadows_for_thing(params = {}) ⇒ Types::ListNamedShadowsForThingResponse
Lists the shadows for the specified thing.
-
#list_retained_messages(params = {}) ⇒ Types::ListRetainedMessagesResponse
Lists summary information about the retained messages stored for the account.
-
#list_subscriptions(params = {}) ⇒ Types::ListSubscriptionsResponse
Returns a list of all subscriptions for MQTT clients with active sessions, including offline clients with persistent sessions.
-
#publish(params = {}) ⇒ Struct
Publishes an MQTT message.
-
#send_direct_message(params = {}) ⇒ Types::SendDirectMessageResponse
Sends an MQTT message directly to a specific client identified by its client ID.
-
#update_thing_shadow(params = {}) ⇒ Types::UpdateThingShadowResponse
Updates the shadow for the specified thing.
Class Method Summary collapse
- .errors_module ⇒ Object private
Instance Method Summary collapse
- #build_request(operation_name, params = {}) ⇒ Object private
-
#initialize(options) ⇒ Client
constructor
A new instance of Client.
- #waiter_names ⇒ Object deprecated private Deprecated.
Constructor Details
#initialize(options) ⇒ Client
Returns a new instance of Client.
471 472 473 |
# File 'lib/aws-sdk-iotdataplane/client.rb', line 471 def initialize(*args) super end |
Class Attribute Details
.identifier ⇒ Object (readonly)
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
1231 1232 1233 |
# File 'lib/aws-sdk-iotdataplane/client.rb', line 1231 def identifier @identifier end |
Class Method Details
.errors_module ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
1234 1235 1236 |
# File 'lib/aws-sdk-iotdataplane/client.rb', line 1234 def errors_module Errors end |
Instance Method Details
#build_request(operation_name, params = {}) ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
1204 1205 1206 1207 1208 1209 1210 1211 1212 1213 1214 1215 1216 1217 1218 1219 1220 |
# File 'lib/aws-sdk-iotdataplane/client.rb', line 1204 def build_request(operation_name, params = {}) handlers = @handlers.for(operation_name) tracer = config.telemetry_provider.tracer_provider.tracer( Aws::Telemetry.module_to_tracer_name('Aws::IoTDataPlane') ) context = Seahorse::Client::RequestContext.new( operation_name: operation_name, operation: config.api.operation(operation_name), client: self, params: params, config: config, tracer: tracer ) context[:gem_name] = 'aws-sdk-iotdataplane' context[:gem_version] = '1.92.0' Seahorse::Client::Request.new(handlers, context) end |
#delete_connection(params = {}) ⇒ Struct
Disconnects a connected MQTT client from Amazon Web Services IoT Core. When you disconnect a client, Amazon Web Services IoT Core closes the client’s network connection and optionally cleans the session state.
Requires permission to access the [DeleteConnection] action.
526 527 528 529 |
# File 'lib/aws-sdk-iotdataplane/client.rb', line 526 def delete_connection(params = {}, = {}) req = build_request(:delete_connection, params) req.send_request() end |
#delete_thing_shadow(params = {}) ⇒ Types::DeleteThingShadowResponse
Deletes the shadow for the specified thing.
Requires permission to access the [DeleteThingShadow] action.
For more information, see [DeleteThingShadow] in the IoT Developer Guide.
[1]: docs.aws.amazon.com/service-authorization/latest/reference/list_awsiot.html#awsiot-actions-as-permissions [2]: docs.aws.amazon.com/iot/latest/developerguide/API_DeleteThingShadow.html
566 567 568 569 |
# File 'lib/aws-sdk-iotdataplane/client.rb', line 566 def delete_thing_shadow(params = {}, = {}) req = build_request(:delete_thing_shadow, params) req.send_request() end |
#get_connection(params = {}) ⇒ Types::GetConnectionResponse
Retrieves connection information for the specified MQTT client.
Requires permission to access the [GetConnection] action.
641 642 643 644 |
# File 'lib/aws-sdk-iotdataplane/client.rb', line 641 def get_connection(params = {}, = {}) req = build_request(:get_connection, params) req.send_request() end |
#get_retained_message(params = {}) ⇒ Types::GetRetainedMessageResponse
Gets the details of a single retained message for the specified topic.
This action returns the message payload of the retained message, which can incur messaging costs. To list only the topic names of the retained messages, call [ListRetainedMessages].
Requires permission to access the [GetRetainedMessage] action.
For more information about messaging costs, see [Amazon Web Services IoT Core pricing - Messaging].
[1]: docs.aws.amazon.com/iot/latest/apireference/API_iotdata_ListRetainedMessages.html [2]: docs.aws.amazon.com/service-authorization/latest/reference/list_awsiot.html [3]: aws.amazon.com/iot-core/pricing/#Messaging
690 691 692 693 |
# File 'lib/aws-sdk-iotdataplane/client.rb', line 690 def (params = {}, = {}) req = build_request(:get_retained_message, params) req.send_request() end |
#get_thing_shadow(params = {}) ⇒ Types::GetThingShadowResponse
Gets the shadow for the specified thing.
Requires permission to access the [GetThingShadow] action.
For more information, see [GetThingShadow] in the IoT Developer Guide.
[1]: docs.aws.amazon.com/service-authorization/latest/reference/list_awsiot.html#awsiot-actions-as-permissions [2]: docs.aws.amazon.com/iot/latest/developerguide/API_GetThingShadow.html
730 731 732 733 |
# File 'lib/aws-sdk-iotdataplane/client.rb', line 730 def get_thing_shadow(params = {}, = {}) req = build_request(:get_thing_shadow, params) req.send_request() end |
#list_named_shadows_for_thing(params = {}) ⇒ Types::ListNamedShadowsForThingResponse
Lists the shadows for the specified thing.
Requires permission to access the [ListNamedShadowsForThing] action.
776 777 778 779 |
# File 'lib/aws-sdk-iotdataplane/client.rb', line 776 def list_named_shadows_for_thing(params = {}, = {}) req = build_request(:list_named_shadows_for_thing, params) req.send_request() end |
#list_retained_messages(params = {}) ⇒ Types::ListRetainedMessagesResponse
Lists summary information about the retained messages stored for the account.
This action returns only the topic names of the retained messages. It doesn’t return any message payloads. Although this action doesn’t return a message payload, it can still incur messaging costs.
To get the message payload of a retained message, call
- GetRetainedMessage][1
-
with the topic name of the retained message.
Requires permission to access the [ListRetainedMessages] action.
For more information about messaging costs, see [Amazon Web Services IoT Core pricing - Messaging].
[1]: docs.aws.amazon.com/iot/latest/apireference/API_iotdata_GetRetainedMessage.html [2]: docs.aws.amazon.com/service-authorization/latest/reference/list_awsiot.html [3]: aws.amazon.com/iot-core/pricing/#Messaging
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
835 836 837 838 |
# File 'lib/aws-sdk-iotdataplane/client.rb', line 835 def (params = {}, = {}) req = build_request(:list_retained_messages, params) req.send_request() end |
#list_subscriptions(params = {}) ⇒ Types::ListSubscriptionsResponse
Returns a list of all subscriptions for MQTT clients with active sessions, including offline clients with persistent sessions.
Requires permission to access the [ListSubscriptions] action.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
890 891 892 893 |
# File 'lib/aws-sdk-iotdataplane/client.rb', line 890 def list_subscriptions(params = {}, = {}) req = build_request(:list_subscriptions, params) req.send_request() end |
#publish(params = {}) ⇒ Struct
Publishes an MQTT message.
Requires permission to access the [Publish] action.
For more information about MQTT messages, see [MQTT Protocol] in the IoT Developer Guide.
For more information about messaging costs, see [Amazon Web Services IoT Core pricing - Messaging].
[1]: docs.aws.amazon.com/service-authorization/latest/reference/list_awsiot.html#awsiot-actions-as-permissions [2]: docs.aws.amazon.com/iot/latest/developerguide/mqtt.html [3]: aws.amazon.com/iot-core/pricing/#Messaging
1001 1002 1003 1004 |
# File 'lib/aws-sdk-iotdataplane/client.rb', line 1001 def publish(params = {}, = {}) req = build_request(:publish, params) req.send_request() end |
#send_direct_message(params = {}) ⇒ Types::SendDirectMessageResponse
Sends an MQTT message directly to a specific client identified by its client ID.
‘SendDirectMessage` targets a single client ID. The receiving client does not need to subscribe to the topic, but the receiver’s policy must allow ‘iot:Receive` on the specified topic.
Requires permission to access the [SendDirectMessage] action.
For more information about messaging costs, see [Amazon Web Services IoT Core pricing].
[1]: docs.aws.amazon.com/service-authorization/latest/reference/list_awsiot.html#awsiot-actions-as-permissions [2]: aws.amazon.com/iot-core/pricing/
1151 1152 1153 1154 |
# File 'lib/aws-sdk-iotdataplane/client.rb', line 1151 def (params = {}, = {}) req = build_request(:send_direct_message, params) req.send_request() end |
#update_thing_shadow(params = {}) ⇒ Types::UpdateThingShadowResponse
Updates the shadow for the specified thing.
Requires permission to access the [UpdateThingShadow] action.
For more information, see [UpdateThingShadow] in the IoT Developer Guide.
[1]: docs.aws.amazon.com/service-authorization/latest/reference/list_awsiot.html#awsiot-actions-as-permissions [2]: docs.aws.amazon.com/iot/latest/developerguide/API_UpdateThingShadow.html
1195 1196 1197 1198 |
# File 'lib/aws-sdk-iotdataplane/client.rb', line 1195 def update_thing_shadow(params = {}, = {}) req = build_request(:update_thing_shadow, params) req.send_request() end |
#waiter_names ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
1224 1225 1226 |
# File 'lib/aws-sdk-iotdataplane/client.rb', line 1224 def waiter_names [] end |