Class: Aws::IoTDataPlane::Client
- Inherits:
-
Seahorse::Client::Base
- Object
- Seahorse::Client::Base
- Aws::IoTDataPlane::Client
- Includes:
- ClientStubs
- Defined in:
- lib/aws-sdk-iotdataplane/client.rb
Overview
An API client for IoTDataPlane. To construct a client, you need to configure a ‘:region` and `:credentials`.
client = Aws::IoTDataPlane::Client.new(
region: region_name,
credentials: credentials,
# ...
)
For details on configuring region and credentials see the [developer guide](/sdk-for-ruby/v3/developer-guide/setup-config.html).
See #initialize for a full list of supported configuration options.
Class Attribute Summary collapse
- .identifier ⇒ Object readonly private
API Operations collapse
-
#delete_connection(params = {}) ⇒ Struct
Disconnects a connected MQTT client from Amazon Web Services IoT Core.
-
#delete_thing_shadow(params = {}) ⇒ Types::DeleteThingShadowResponse
Deletes the shadow for the specified thing.
-
#get_retained_message(params = {}) ⇒ Types::GetRetainedMessageResponse
Gets the details of a single retained message for the specified topic.
-
#get_thing_shadow(params = {}) ⇒ Types::GetThingShadowResponse
Gets the shadow for the specified thing.
-
#list_named_shadows_for_thing(params = {}) ⇒ Types::ListNamedShadowsForThingResponse
Lists the shadows for the specified thing.
-
#list_retained_messages(params = {}) ⇒ Types::ListRetainedMessagesResponse
Lists summary information about the retained messages stored for the account.
-
#publish(params = {}) ⇒ Struct
Publishes an MQTT message.
-
#update_thing_shadow(params = {}) ⇒ Types::UpdateThingShadowResponse
Updates the shadow for the specified thing.
Class Method Summary collapse
- .errors_module ⇒ Object private
Instance Method Summary collapse
- #build_request(operation_name, params = {}) ⇒ Object private
-
#initialize(options) ⇒ Client
constructor
A new instance of Client.
- #waiter_names ⇒ Object deprecated private Deprecated.
Constructor Details
#initialize(options) ⇒ Client
Returns a new instance of Client.
471 472 473 |
# File 'lib/aws-sdk-iotdataplane/client.rb', line 471 def initialize(*args) super end |
Class Attribute Details
.identifier ⇒ Object (readonly)
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
936 937 938 |
# File 'lib/aws-sdk-iotdataplane/client.rb', line 936 def identifier @identifier end |
Class Method Details
.errors_module ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
939 940 941 |
# File 'lib/aws-sdk-iotdataplane/client.rb', line 939 def errors_module Errors end |
Instance Method Details
#build_request(operation_name, params = {}) ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
909 910 911 912 913 914 915 916 917 918 919 920 921 922 923 924 925 |
# File 'lib/aws-sdk-iotdataplane/client.rb', line 909 def build_request(operation_name, params = {}) handlers = @handlers.for(operation_name) tracer = config.telemetry_provider.tracer_provider.tracer( Aws::Telemetry.module_to_tracer_name('Aws::IoTDataPlane') ) context = Seahorse::Client::RequestContext.new( operation_name: operation_name, operation: config.api.operation(operation_name), client: self, params: params, config: config, tracer: tracer ) context[:gem_name] = 'aws-sdk-iotdataplane' context[:gem_version] = '1.91.0' Seahorse::Client::Request.new(handlers, context) end |
#delete_connection(params = {}) ⇒ Struct
Disconnects a connected MQTT client from Amazon Web Services IoT Core. When you disconnect a client, Amazon Web Services IoT Core closes the client’s network connection and optionally cleans the session state.
511 512 513 514 |
# File 'lib/aws-sdk-iotdataplane/client.rb', line 511 def delete_connection(params = {}, = {}) req = build_request(:delete_connection, params) req.send_request() end |
#delete_thing_shadow(params = {}) ⇒ Types::DeleteThingShadowResponse
Deletes the shadow for the specified thing.
Requires permission to access the [DeleteThingShadow] action.
For more information, see [DeleteThingShadow] in the IoT Developer Guide.
[1]: docs.aws.amazon.com/service-authorization/latest/reference/list_awsiot.html#awsiot-actions-as-permissions [2]: docs.aws.amazon.com/iot/latest/developerguide/API_DeleteThingShadow.html
551 552 553 554 |
# File 'lib/aws-sdk-iotdataplane/client.rb', line 551 def delete_thing_shadow(params = {}, = {}) req = build_request(:delete_thing_shadow, params) req.send_request() end |
#get_retained_message(params = {}) ⇒ Types::GetRetainedMessageResponse
Gets the details of a single retained message for the specified topic.
This action returns the message payload of the retained message, which can incur messaging costs. To list only the topic names of the retained messages, call [ListRetainedMessages].
Requires permission to access the [GetRetainedMessage] action.
For more information about messaging costs, see [Amazon Web Services IoT Core pricing - Messaging].
[1]: docs.aws.amazon.com/iot/latest/apireference/API_iotdata_ListRetainedMessages.html [2]: docs.aws.amazon.com/service-authorization/latest/reference/list_awsiot.html [3]: aws.amazon.com/iot-core/pricing/#Messaging
600 601 602 603 |
# File 'lib/aws-sdk-iotdataplane/client.rb', line 600 def (params = {}, = {}) req = build_request(:get_retained_message, params) req.send_request() end |
#get_thing_shadow(params = {}) ⇒ Types::GetThingShadowResponse
Gets the shadow for the specified thing.
Requires permission to access the [GetThingShadow] action.
For more information, see [GetThingShadow] in the IoT Developer Guide.
[1]: docs.aws.amazon.com/service-authorization/latest/reference/list_awsiot.html#awsiot-actions-as-permissions [2]: docs.aws.amazon.com/iot/latest/developerguide/API_GetThingShadow.html
640 641 642 643 |
# File 'lib/aws-sdk-iotdataplane/client.rb', line 640 def get_thing_shadow(params = {}, = {}) req = build_request(:get_thing_shadow, params) req.send_request() end |
#list_named_shadows_for_thing(params = {}) ⇒ Types::ListNamedShadowsForThingResponse
Lists the shadows for the specified thing.
Requires permission to access the [ListNamedShadowsForThing] action.
686 687 688 689 |
# File 'lib/aws-sdk-iotdataplane/client.rb', line 686 def list_named_shadows_for_thing(params = {}, = {}) req = build_request(:list_named_shadows_for_thing, params) req.send_request() end |
#list_retained_messages(params = {}) ⇒ Types::ListRetainedMessagesResponse
Lists summary information about the retained messages stored for the account.
This action returns only the topic names of the retained messages. It doesn’t return any message payloads. Although this action doesn’t return a message payload, it can still incur messaging costs.
To get the message payload of a retained message, call
- GetRetainedMessage][1
-
with the topic name of the retained message.
Requires permission to access the [ListRetainedMessages] action.
For more information about messaging costs, see [Amazon Web Services IoT Core pricing - Messaging].
[1]: docs.aws.amazon.com/iot/latest/apireference/API_iotdata_GetRetainedMessage.html [2]: docs.aws.amazon.com/service-authorization/latest/reference/list_awsiot.html [3]: aws.amazon.com/iot-core/pricing/#Messaging
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
745 746 747 748 |
# File 'lib/aws-sdk-iotdataplane/client.rb', line 745 def (params = {}, = {}) req = build_request(:list_retained_messages, params) req.send_request() end |
#publish(params = {}) ⇒ Struct
Publishes an MQTT message.
Requires permission to access the [Publish] action.
For more information about MQTT messages, see [MQTT Protocol] in the IoT Developer Guide.
For more information about messaging costs, see [Amazon Web Services IoT Core pricing - Messaging].
[1]: docs.aws.amazon.com/service-authorization/latest/reference/list_awsiot.html#awsiot-actions-as-permissions [2]: docs.aws.amazon.com/iot/latest/developerguide/mqtt.html [3]: aws.amazon.com/iot-core/pricing/#Messaging
856 857 858 859 |
# File 'lib/aws-sdk-iotdataplane/client.rb', line 856 def publish(params = {}, = {}) req = build_request(:publish, params) req.send_request() end |
#update_thing_shadow(params = {}) ⇒ Types::UpdateThingShadowResponse
Updates the shadow for the specified thing.
Requires permission to access the [UpdateThingShadow] action.
For more information, see [UpdateThingShadow] in the IoT Developer Guide.
[1]: docs.aws.amazon.com/service-authorization/latest/reference/list_awsiot.html#awsiot-actions-as-permissions [2]: docs.aws.amazon.com/iot/latest/developerguide/API_UpdateThingShadow.html
900 901 902 903 |
# File 'lib/aws-sdk-iotdataplane/client.rb', line 900 def update_thing_shadow(params = {}, = {}) req = build_request(:update_thing_shadow, params) req.send_request() end |
#waiter_names ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
929 930 931 |
# File 'lib/aws-sdk-iotdataplane/client.rb', line 929 def waiter_names [] end |