Class: Aws::IoTDataPlane::Types::DeleteConnectionRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-iotdataplane/types.rb

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#clean_sessionBoolean

Specifies whether to remove the client’s persistent session state when disconnecting. Set to ‘TRUE` to delete all session information, including subscriptions and queued messages. Set to `FALSE` to preserve the session state for [persistent sessions]. For clean sessions this parameter will be ignored. By default, this is set to `FALSE` (preserves the session state).

[1]: docs.aws.amazon.com/iot/latest/developerguide/mqtt.html#mqtt-persistent-sessions

Returns:

  • (Boolean)


55
56
57
58
59
60
61
# File 'lib/aws-sdk-iotdataplane/types.rb', line 55

class DeleteConnectionRequest < Struct.new(
  :client_id,
  :clean_session,
  :prevent_will_message)
  SENSITIVE = []
  include Aws::Structure
end

#client_idString

The unique identifier of the MQTT client to disconnect. The client ID can’t start with a dollar sign ($).

MQTT client IDs must be URL encoded (percent-encoded) when they contain characters that are not valid in HTTP requests, such as spaces, forward slashes (/), and UTF-8 characters.

Returns:

  • (String)


55
56
57
58
59
60
61
# File 'lib/aws-sdk-iotdataplane/types.rb', line 55

class DeleteConnectionRequest < Struct.new(
  :client_id,
  :clean_session,
  :prevent_will_message)
  SENSITIVE = []
  include Aws::Structure
end

#prevent_will_messageBoolean

Controls if Amazon Web Services IoT Core publishes the client’s Last Will and Testament (LWT) message upon disconnection. Set to ‘TRUE` to prevent publishing the LWT message. Set to `FALSE` to ensure that LWT is published. By default, this is set to `FALSE` (LWT message is published).

Returns:

  • (Boolean)


55
56
57
58
59
60
61
# File 'lib/aws-sdk-iotdataplane/types.rb', line 55

class DeleteConnectionRequest < Struct.new(
  :client_id,
  :clean_session,
  :prevent_will_message)
  SENSITIVE = []
  include Aws::Structure
end