Class: Aws::IoTDataPlane::Types::GetConnectionResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::IoTDataPlane::Types::GetConnectionResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-iotdataplane/types.rb
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#clean_session ⇒ Boolean
Indicates whether the client is using a clean session.
-
#client_id ⇒ String
The unique identifier of the MQTT client.
-
#connected ⇒ Boolean
The connection state of the client.
-
#connected_since ⇒ Integer
Unix timestamp (in milliseconds) indicating when the client connected.
-
#disconnect_reason ⇒ String
The reason for the last disconnection, if the client is currently disconnected.
-
#disconnected_since ⇒ Integer
Unix timestamp (in milliseconds) indicating when the client disconnected.
-
#keep_alive_duration ⇒ Integer
The keep-alive interval in seconds that the client specified when establishing the connection.
-
#session_expiry ⇒ Integer
The session expiry interval in seconds for the MQTT client connection.
-
#source_ip ⇒ String
The IP address of the client that initiated the connection.
-
#source_port ⇒ Integer
The client’s source port.
-
#target_ip ⇒ String
The IP address of the Amazon Web Services IoT Core endpoint that the client connected to.
-
#target_port ⇒ Integer
The port number of the Amazon Web Services IoT Core endpoint that the client connected to.
-
#thing_name ⇒ String
The name of the thing associated with the principal of the MQTT client, if applicable.
-
#vpc_endpoint_id ⇒ String
The ID of the VPC endpoint.
Instance Attribute Details
#clean_session ⇒ Boolean
Indicates whether the client is using a clean session. Returns ‘true` for clean sessions or `false` for persistent sessions.
225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 |
# File 'lib/aws-sdk-iotdataplane/types.rb', line 225 class GetConnectionResponse < Struct.new( :connected, :thing_name, :clean_session, :source_ip, :source_port, :target_ip, :target_port, :keep_alive_duration, :connected_since, :disconnected_since, :disconnect_reason, :session_expiry, :client_id, :vpc_endpoint_id) SENSITIVE = [] include Aws::Structure end |
#client_id ⇒ String
The unique identifier of the MQTT client. This is the same client ID that was used when the client established the connection.
225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 |
# File 'lib/aws-sdk-iotdataplane/types.rb', line 225 class GetConnectionResponse < Struct.new( :connected, :thing_name, :clean_session, :source_ip, :source_port, :target_ip, :target_port, :keep_alive_duration, :connected_since, :disconnected_since, :disconnect_reason, :session_expiry, :client_id, :vpc_endpoint_id) SENSITIVE = [] include Aws::Structure end |
#connected ⇒ Boolean
The connection state of the client. Returns ‘true` if the client is currently connected, or `false` if the client is not connected.
225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 |
# File 'lib/aws-sdk-iotdataplane/types.rb', line 225 class GetConnectionResponse < Struct.new( :connected, :thing_name, :clean_session, :source_ip, :source_port, :target_ip, :target_port, :keep_alive_duration, :connected_since, :disconnected_since, :disconnect_reason, :session_expiry, :client_id, :vpc_endpoint_id) SENSITIVE = [] include Aws::Structure end |
#connected_since ⇒ Integer
Unix timestamp (in milliseconds) indicating when the client connected. Present only when connected is true.
225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 |
# File 'lib/aws-sdk-iotdataplane/types.rb', line 225 class GetConnectionResponse < Struct.new( :connected, :thing_name, :clean_session, :source_ip, :source_port, :target_ip, :target_port, :keep_alive_duration, :connected_since, :disconnected_since, :disconnect_reason, :session_expiry, :client_id, :vpc_endpoint_id) SENSITIVE = [] include Aws::Structure end |
#disconnect_reason ⇒ String
The reason for the last disconnection, if the client is currently disconnected. See the [developer guide] for valid disconnect reasons.
[1]: docs.aws.amazon.com/iot/latest/developerguide/life-cycle-events.html#connect-disconnect
225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 |
# File 'lib/aws-sdk-iotdataplane/types.rb', line 225 class GetConnectionResponse < Struct.new( :connected, :thing_name, :clean_session, :source_ip, :source_port, :target_ip, :target_port, :keep_alive_duration, :connected_since, :disconnected_since, :disconnect_reason, :session_expiry, :client_id, :vpc_endpoint_id) SENSITIVE = [] include Aws::Structure end |
#disconnected_since ⇒ Integer
Unix timestamp (in milliseconds) indicating when the client disconnected. Present only when connected is false. This information is available for 30 minutes after the client disconnects.
225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 |
# File 'lib/aws-sdk-iotdataplane/types.rb', line 225 class GetConnectionResponse < Struct.new( :connected, :thing_name, :clean_session, :source_ip, :source_port, :target_ip, :target_port, :keep_alive_duration, :connected_since, :disconnected_since, :disconnect_reason, :session_expiry, :client_id, :vpc_endpoint_id) SENSITIVE = [] include Aws::Structure end |
#keep_alive_duration ⇒ Integer
The keep-alive interval in seconds that the client specified when establishing the connection.
225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 |
# File 'lib/aws-sdk-iotdataplane/types.rb', line 225 class GetConnectionResponse < Struct.new( :connected, :thing_name, :clean_session, :source_ip, :source_port, :target_ip, :target_port, :keep_alive_duration, :connected_since, :disconnected_since, :disconnect_reason, :session_expiry, :client_id, :vpc_endpoint_id) SENSITIVE = [] include Aws::Structure end |
#session_expiry ⇒ Integer
The session expiry interval in seconds for the MQTT client connection. This is configured by the user. This value indicates how long the session will remain active after the client disconnects.
225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 |
# File 'lib/aws-sdk-iotdataplane/types.rb', line 225 class GetConnectionResponse < Struct.new( :connected, :thing_name, :clean_session, :source_ip, :source_port, :target_ip, :target_port, :keep_alive_duration, :connected_since, :disconnected_since, :disconnect_reason, :session_expiry, :client_id, :vpc_endpoint_id) SENSITIVE = [] include Aws::Structure end |
#source_ip ⇒ String
The IP address of the client that initiated the connection.
225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 |
# File 'lib/aws-sdk-iotdataplane/types.rb', line 225 class GetConnectionResponse < Struct.new( :connected, :thing_name, :clean_session, :source_ip, :source_port, :target_ip, :target_port, :keep_alive_duration, :connected_since, :disconnected_since, :disconnect_reason, :session_expiry, :client_id, :vpc_endpoint_id) SENSITIVE = [] include Aws::Structure end |
#source_port ⇒ Integer
The client’s source port.
225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 |
# File 'lib/aws-sdk-iotdataplane/types.rb', line 225 class GetConnectionResponse < Struct.new( :connected, :thing_name, :clean_session, :source_ip, :source_port, :target_ip, :target_port, :keep_alive_duration, :connected_since, :disconnected_since, :disconnect_reason, :session_expiry, :client_id, :vpc_endpoint_id) SENSITIVE = [] include Aws::Structure end |
#target_ip ⇒ String
The IP address of the Amazon Web Services IoT Core endpoint that the client connected to. For clients connected to VPC endpoints, this is the private IP address of the network interface the client is connected to.
225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 |
# File 'lib/aws-sdk-iotdataplane/types.rb', line 225 class GetConnectionResponse < Struct.new( :connected, :thing_name, :clean_session, :source_ip, :source_port, :target_ip, :target_port, :keep_alive_duration, :connected_since, :disconnected_since, :disconnect_reason, :session_expiry, :client_id, :vpc_endpoint_id) SENSITIVE = [] include Aws::Structure end |
#target_port ⇒ Integer
The port number of the Amazon Web Services IoT Core endpoint that the client connected to.
225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 |
# File 'lib/aws-sdk-iotdataplane/types.rb', line 225 class GetConnectionResponse < Struct.new( :connected, :thing_name, :clean_session, :source_ip, :source_port, :target_ip, :target_port, :keep_alive_duration, :connected_since, :disconnected_since, :disconnect_reason, :session_expiry, :client_id, :vpc_endpoint_id) SENSITIVE = [] include Aws::Structure end |
#thing_name ⇒ String
The name of the thing associated with the principal of the MQTT client, if applicable.
225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 |
# File 'lib/aws-sdk-iotdataplane/types.rb', line 225 class GetConnectionResponse < Struct.new( :connected, :thing_name, :clean_session, :source_ip, :source_port, :target_ip, :target_port, :keep_alive_duration, :connected_since, :disconnected_since, :disconnect_reason, :session_expiry, :client_id, :vpc_endpoint_id) SENSITIVE = [] include Aws::Structure end |
#vpc_endpoint_id ⇒ String
The ID of the VPC endpoint. Present for clients connected to IoT Core via a [VPC endpoint].
[1]: docs.aws.amazon.com/iot/latest/developerguide/IoTCore-VPC.html
225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 |
# File 'lib/aws-sdk-iotdataplane/types.rb', line 225 class GetConnectionResponse < Struct.new( :connected, :thing_name, :clean_session, :source_ip, :source_port, :target_ip, :target_port, :keep_alive_duration, :connected_since, :disconnected_since, :disconnect_reason, :session_expiry, :client_id, :vpc_endpoint_id) SENSITIVE = [] include Aws::Structure end |