Class: Aws::IoTDataPlane::Types::ListSubscriptionsRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::IoTDataPlane::Types::ListSubscriptionsRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-iotdataplane/types.rb
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#client_id ⇒ String
The unique identifier of the MQTT client to list subscriptions for.
-
#max_results ⇒ Integer
The maximum number of subscriptions to return in a single request.
-
#next_token ⇒ String
To retrieve the next set of results, the
nextTokenvalue from a previous response; otherwise null to receive the first set of results.
Instance Attribute Details
#client_id ⇒ String
The unique identifier of the MQTT client to list subscriptions for. The client ID can't start with a dollar sign ($).
MQTT client IDs must be URL encoded (percent-encoded) when they contain characters that are not valid in HTTP requests, such as spaces, forward slashes (/), and UTF-8 characters.
447 448 449 450 451 452 453 |
# File 'lib/aws-sdk-iotdataplane/types.rb', line 447 class ListSubscriptionsRequest < Struct.new( :client_id, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |
#max_results ⇒ Integer
The maximum number of subscriptions to return in a single request. By default, this is set to 20.
447 448 449 450 451 452 453 |
# File 'lib/aws-sdk-iotdataplane/types.rb', line 447 class ListSubscriptionsRequest < Struct.new( :client_id, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
To retrieve the next set of results, the nextToken value from a
previous response; otherwise null to receive the first set of
results.
447 448 449 450 451 452 453 |
# File 'lib/aws-sdk-iotdataplane/types.rb', line 447 class ListSubscriptionsRequest < Struct.new( :client_id, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |