Class: Aws::IoTDataPlane::Types::SendDirectMessageRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::IoTDataPlane::Types::SendDirectMessageRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-iotdataplane/types.rb
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#client_id ⇒ String
The unique identifier of the MQTT client to send the message to.
-
#confirmation ⇒ Boolean
A Boolean value that specifies whether to wait for delivery confirmation from the receiving client.
-
#content_type ⇒ String
The MQTT5 content type property forwarded to the receiving client (for example, ‘application/json`).
-
#correlation_data ⇒ String
The base64-encoded binary data used by the sender of the request message to identify which request the response message is for when it’s received.
-
#payload ⇒ String
The message body.
-
#payload_format_indicator ⇒ String
An ‘Enum` string value that indicates whether the payload is formatted as UTF-8.
-
#response_topic ⇒ String
A UTF-8 encoded string that’s used as the topic name for a response message.
-
#timeout ⇒ Integer
An integer that represents the maximum time, in seconds, to wait for a delivery confirmation (PUBACK) from the receiving client after the message has been delivered.
-
#topic ⇒ String
The topic of the outbound MQTT Publish message to the receiving client.
-
#user_properties ⇒ String
A JSON string that contains an array of JSON objects.
Instance Attribute Details
#client_id ⇒ String
The unique identifier of the MQTT client to send the message to.
Client IDs must not exceed 128 characters and can’t start with a dollar sign ($). MQTT client IDs must be URL encoded (percent-encoded) when they contain characters that are not valid in HTTP requests, such as spaces, forward slashes (/), and UTF-8 characters. For more information, see [Amazon Web Services IoT Core message broker and protocol limits and quotas].
[1]: docs.aws.amazon.com/general/latest/gr/iot-core.html#message-broker-limits
744 745 746 747 748 749 750 751 752 753 754 755 756 757 |
# File 'lib/aws-sdk-iotdataplane/types.rb', line 744 class SendDirectMessageRequest < Struct.new( :client_id, :topic, :content_type, :response_topic, :confirmation, :timeout, :payload, :user_properties, :payload_format_indicator, :correlation_data) SENSITIVE = [] include Aws::Structure end |
#confirmation ⇒ Boolean
A Boolean value that specifies whether to wait for delivery confirmation from the receiving client.
When set to ‘true`, the API delivers the message at QoS 1 and waits for the client to send a delivery confirmation (PUBACK) before returning a successful response. If delivery confirmation is not received within the specified `timeout` period, the API returns HTTP 504.
When set to ‘false`, the API delivers the message at QoS 0 and returns after Amazon Web Services IoT Core attempts to deliver the message.
Valid values: ‘true` | `false`
Default value: ‘false`
744 745 746 747 748 749 750 751 752 753 754 755 756 757 |
# File 'lib/aws-sdk-iotdataplane/types.rb', line 744 class SendDirectMessageRequest < Struct.new( :client_id, :topic, :content_type, :response_topic, :confirmation, :timeout, :payload, :user_properties, :payload_format_indicator, :correlation_data) SENSITIVE = [] include Aws::Structure end |
#content_type ⇒ String
The MQTT5 content type property forwarded to the receiving client (for example, ‘application/json`).
744 745 746 747 748 749 750 751 752 753 754 755 756 757 |
# File 'lib/aws-sdk-iotdataplane/types.rb', line 744 class SendDirectMessageRequest < Struct.new( :client_id, :topic, :content_type, :response_topic, :confirmation, :timeout, :payload, :user_properties, :payload_format_indicator, :correlation_data) SENSITIVE = [] include Aws::Structure end |
#correlation_data ⇒ String
The base64-encoded binary data used by the sender of the request message to identify which request the response message is for when it’s received. ‘correlationData` is an HTTP header value in the API.
744 745 746 747 748 749 750 751 752 753 754 755 756 757 |
# File 'lib/aws-sdk-iotdataplane/types.rb', line 744 class SendDirectMessageRequest < Struct.new( :client_id, :topic, :content_type, :response_topic, :confirmation, :timeout, :payload, :user_properties, :payload_format_indicator, :correlation_data) SENSITIVE = [] include Aws::Structure end |
#payload ⇒ String
The message body. MQTT accepts text, binary, and empty (null) message payloads.
744 745 746 747 748 749 750 751 752 753 754 755 756 757 |
# File 'lib/aws-sdk-iotdataplane/types.rb', line 744 class SendDirectMessageRequest < Struct.new( :client_id, :topic, :content_type, :response_topic, :confirmation, :timeout, :payload, :user_properties, :payload_format_indicator, :correlation_data) SENSITIVE = [] include Aws::Structure end |
#payload_format_indicator ⇒ String
An ‘Enum` string value that indicates whether the payload is formatted as UTF-8. `payloadFormatIndicator` is an HTTP header value in the API.
744 745 746 747 748 749 750 751 752 753 754 755 756 757 |
# File 'lib/aws-sdk-iotdataplane/types.rb', line 744 class SendDirectMessageRequest < Struct.new( :client_id, :topic, :content_type, :response_topic, :confirmation, :timeout, :payload, :user_properties, :payload_format_indicator, :correlation_data) SENSITIVE = [] include Aws::Structure end |
#response_topic ⇒ String
A UTF-8 encoded string that’s used as the topic name for a response message. The response topic describes the topic which the receiver should publish to as part of the request-response flow. The topic must not contain wildcard characters. For more information, see [Amazon Web Services IoT Core message broker and protocol limits and quotas].
[1]: docs.aws.amazon.com/general/latest/gr/iot-core.html#message-broker-limits
744 745 746 747 748 749 750 751 752 753 754 755 756 757 |
# File 'lib/aws-sdk-iotdataplane/types.rb', line 744 class SendDirectMessageRequest < Struct.new( :client_id, :topic, :content_type, :response_topic, :confirmation, :timeout, :payload, :user_properties, :payload_format_indicator, :correlation_data) SENSITIVE = [] include Aws::Structure end |
#timeout ⇒ Integer
An integer that represents the maximum time, in seconds, to wait for a delivery confirmation (PUBACK) from the receiving client after the message has been delivered. This parameter is only used when ‘confirmation` is set to `true`. If `confirmation` is `false`, this parameter is ignored.
The total API response time may be higher than this value due to internal processing. Set your HTTP client timeout to a value greater than this parameter.
Valid range: 1 to 15 seconds.
Default value: ‘5` seconds.
744 745 746 747 748 749 750 751 752 753 754 755 756 757 |
# File 'lib/aws-sdk-iotdataplane/types.rb', line 744 class SendDirectMessageRequest < Struct.new( :client_id, :topic, :content_type, :response_topic, :confirmation, :timeout, :payload, :user_properties, :payload_format_indicator, :correlation_data) SENSITIVE = [] include Aws::Structure end |
#topic ⇒ String
The topic of the outbound MQTT Publish message to the receiving client. For more information, see [Amazon Web Services IoT Core message broker and protocol limits and quotas].
[1]: docs.aws.amazon.com/general/latest/gr/iot-core.html#message-broker-limits
744 745 746 747 748 749 750 751 752 753 754 755 756 757 |
# File 'lib/aws-sdk-iotdataplane/types.rb', line 744 class SendDirectMessageRequest < Struct.new( :client_id, :topic, :content_type, :response_topic, :confirmation, :timeout, :payload, :user_properties, :payload_format_indicator, :correlation_data) SENSITIVE = [] include Aws::Structure end |
#user_properties ⇒ String
A JSON string that contains an array of JSON objects. If you don’t use Amazon Web Services SDK or CLI, you must encode the JSON string to base64 format before adding it to the HTTP header. ‘userProperties` is an HTTP header value in the API.
For MQTT 3.1.1 clients, user properties are silently dropped.
The following example ‘userProperties` parameter is a JSON string which represents two User Properties. Note that it needs to be base64-encoded:
‘[“alpha”, “45”]`
744 745 746 747 748 749 750 751 752 753 754 755 756 757 |
# File 'lib/aws-sdk-iotdataplane/types.rb', line 744 class SendDirectMessageRequest < Struct.new( :client_id, :topic, :content_type, :response_topic, :confirmation, :timeout, :payload, :user_properties, :payload_format_indicator, :correlation_data) SENSITIVE = [] include Aws::Structure end |